@@ -2,27 +2,14 @@
 from operator import getitem
 from typing import Any, Dict, List
 
-from pydantic import BaseModel, PrivateAttr
+from pydantic import BaseModel, Field, PrivateAttr
 from redbird import BaseRepo, BaseResult
 from redbird.templates import TemplateRepo
 from redbird.exc import KeyFoundError
 from redbird.oper import Operation
 from redbird.dummy import DummySession
 
-
-class QueryMatcher:
-
-    def __init__(self, query, value_getter):
-        self.query = query
-        self.value_getter = value_getter
-
-    def __contains__(self, item):
-        "Match whether item fulfills the query"
-        get_value = self.value_getter
-        return all(
-            val.evaluate(get_value(item, key)) if isinstance(val, Operation) else get_value(item, key) == val
-            for key, val in self.query.items()
-        )
+from redbird.utils.query import QueryMatcher
 
 class MemoryRepo(TemplateRepo):
     """Memory repository
@@ -32,6 +19,8 @@ class MemoryRepo(TemplateRepo):
 
     Parameters
     ----------
+    collection : list
+        The collection
     model : Type
         Class of an item in the repository.
         Commonly dict or subclass of Pydantic
@@ -50,8 +39,6 @@ class MemoryRepo(TemplateRepo):
         the item in case of validation error in 
         converting data to the item model from
         the repository. By default raise 
-    collection : list
-        The collection.
     
     Examples
     --------
@@ -69,7 +56,9 @@ class MemoryRepo(TemplateRepo):
     #cls_result = MemoryResult
     collection: List[Any] = []
 
+    ordered: bool = Field(default=False, const=True)
     _session = PrivateAttr()
+    
     def insert(self, item):
         if self.id_field is not None:
             id_ = self.get_field_value(item, self.id_field)
@@ -81,7 +70,7 @@ class MemoryRepo(TemplateRepo):
     def item_to_data(self, item):
         return item
 
-    def query_read(self, query):
+    def query_data(self, query):
         query = QueryMatcher(query, value_getter=self.get_field_value)
         col = self.collection
         for data in col:
